Module api

Module api 

Manga API client

Structs

MangaApiClient
The MangaApiClient provides functions for interacting with the various manga and user mangalist MAL API endpoints. The accessible endpoints vary depending on if the MangaApiClient was constructed from a MalClientId or an OauthClient.

Traits

MangaApi
This trait defines the shared endpoints for Client and Oauth MangaApiClients. It provides default implementations such that the Oauth MangaApiClient can override them if needed.
Request
This trait defines the common request methods available to both Client and Oauth MangaApiClients